@@ -80,6 +80,7 @@ enum pluto_crypto_requests {
   pcr_build_nonce    = 6,
   pcr_compute_dh_iv  = 7,  /* perform phase 1 calculation: DH + prf */
   pcr_compute_dh     = 8,  /* perform phase 2 PFS DH */
+  pcr_compute_dh_v2  = 9,  /* perform IKEv2 PARENT SA calculation, create SKEYSEED */
 };
 
 /*
@@ -246,9 +247,24 @@ enum state_kind {
 
     STATE_XAUTH_I0,              /* client state is awaiting request */
     STATE_XAUTH_I1,              /* client state is awaiting result code */
+    STATE_IKE_ROOF,
 
-    STATE_IKE_ROOF
+    /* IKEv2 states.
+     * Note that message reliably sending is done by initiator only,
+     * unlike with IKEv1.
+     */
+    STATE_IKEv2_BASE,
+    /* INITIATOR states */
+    STATE_PARENT_I1,           /* sent initial message, waiting for reply */
+    STATE_PARENT_I2,           /* sent auth message, waiting for reply */
+    STATE_PARENT_I3,           /* received auth message, done. */
 
+    /* RESPONDER states  --- no real actions, initiator is responsible
+     * for all work states. */
+    STATE_PARENT_R1,
+    STATE_PARENT_R2,
+    
+    STATE_IKEv2_ROOF,
 };
 
 enum phase1_role {
@@ -290,6 +306,12 @@ enum phase1_role {
 #define IS_MODE_CFG_ESTABLISHED(s) ((s) == STATE_MODE_CFG_R2)
 #endif
 
+#define IS_PARENT_SA_ESTABLISHED(s) ((s) == STATE_PARENT_I2 || (s) == STATE_PARENT_R1)
+#define IS_CHILD_SA_ESTABLISHED(s)  ((s) == STATE_PARENT_I3 || (s) == STATE_PARENT_R2)
+
+
+
+
 /* kind of struct connection
  * Ordered (mostly) by concreteness.  Order is exploited.
  */
@@ -336,6 +358,13 @@ enum certpolicy {
 #define cert_defaultcertpolicy cert_sendifasked
 
 
+enum four_options {
+	fo_never   = 0,  /* do not propose, do not permit */
+	fo_permit  = 1,  /* do not propose, but permit peer to propose */
+	fo_propose = 2,  /* propose, and permit, but do not insist  */
+	fo_insist  = 3   /* propose, and only accept if peer agrees */
+};
+
 /* Policies for establishing an SA
  *
  * These are used to specify attributes (eg. encryption) and techniques
@@ -403,10 +432,16 @@ enum pluto_policy {
 	POLICY_SUBHOST      = LELEM(21),   /* if the policy applies below the host level (TCP/UDP/SCTP ports), */
 	POLICY_PERPROTO     = LELEM(22),   /* should we specialize the policy to the protocol? */
 	POLICY_OVERLAPIP    = LELEM(23),   /* can two conns that have subnet=vhost: declare the same IP? */
-	POLICY_MODECFGDNS1  = LELEM(24),   /* should we offer a DNS server IP */
-	POLICY_MODECFGDNS2  = LELEM(25),   /* should we offer another DNS server IP */
-	POLICY_MODECFGWINS1 = LELEM(26),   /* should we offer a WINS server IP */
-	POLICY_MODECFGWINS2 = LELEM(27),   /* should we offer another WINS server IP */
+
+	/*
+	 * this is mapped by parser's ikev2={four_state}. It is a bit richer
+	 * in that we can actually turn off everything, but it expands more
+	 * sensibly to an IKEv3 and other methods.
+	 */
+	POLICY_IKEV1_DISABLE = LELEM(24), /* !accept IKEv1?  0x0100 0000 */
+	POLICY_IKEV2_ALLOW   = LELEM(25), /* accept IKEv2?   0x0200 0000 */
+	POLICY_IKEV2_PROPOSE = LELEM(26), /* propose IKEv2?  0x0400 0000 */
+	POLICY_IKEV2_MASK = POLICY_IKEV1_DISABLE|POLICY_IKEV2_ALLOW|POLICY_IKEV2_PROPOSE,
 };
 
 /* Any IPsec policy?  If not, a connection description
@@ -503,20 +538,6 @@ enum pluto_policy {
 #define ENCAPSULATION_MODE_UDP_TRANSPORT_RFC       4
 #endif
 
-/* Auth Algorithm attribute */
-
-
-#define AUTH_ALGORITHM_NONE        0	/* our private designation */
-#define AUTH_ALGORITHM_HMAC_MD5    1
-#define AUTH_ALGORITHM_HMAC_SHA1   2
-#define AUTH_ALGORITHM_DES_MAC     3
-#define AUTH_ALGORITHM_KPDK        4
-#define AUTH_ALGORITHM_HMAC_SHA2_256   5
-#define AUTH_ALGORITHM_HMAC_SHA2_384   6
-#define AUTH_ALGORITHM_HMAC_SHA2_512   7
-#define AUTH_ALGORITHM_HMAC_RIPEMD     8
-
-
 /* Oakley Lifetime Type attribute
  * draft-ietf-ipsec-ike-01.txt appendix A
  * As far as I can see, there is not specification for
