@@ -194,17 +194,19 @@ struct whack_message {
     /* for WHACK_REREAD */
     u_char whack_reread;
 
-    /* for WHACK_TCPEVAL */
-    char *tpmeval;
-
-    /* for connalias string */
-    char *connalias;
-
+#ifdef MODECFG_DNSWINS
     /* for MODECFG */
     ip_address modecfg_dns1;
     ip_address modecfg_dns2;
     ip_address modecfg_wins1;
     ip_address modecfg_wins2;
+#endif
+
+    /* for WHACK_TCPEVAL */
+    char *tpmeval;
+
+    /* for connalias string */
+    char *connalias;
 
     /* for use with general option adjustments */
     enum whack_opt_set opt_set;
@@ -293,6 +295,8 @@ extern size_t whack_get_secret(char *buf, size_t bufsize);
 extern int whack_get_value(char *buf, size_t bufsize);
 
 extern bool osw_alias_cmp(const char *needle, const char *haystack);
+extern void whack_process(int whackfd, struct whack_message msg);
+
 #endif /* _WHACK_H */
 
 /*
