@@ -14,7 +14,6 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: ipsec_kversion.h,v 1.15.2.24 2008-04-11 00:30:07 paul Exp $
  */
 #define	_OPENSWAN_KVERSIONS_H	/* seen it, no need to see it again */
 
@@ -55,12 +54,6 @@
 #  ifndef CONFIG_IP_ALIAS
 #  define CONFIG_IP_ALIAS
 #  endif
-#include <linux/socket.h>
-#include <linux/skbuff.h>
-#include <linux/netlink.h>
-#  ifdef NETLINK_XFRM
-#  define NETDEV_25
-#  endif
 #endif
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,3,25)
@@ -116,6 +109,7 @@
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
 #define HAVE_NETDEV_PRINTK 1
 #define NET_26
+#define NETDEV_25
 #endif
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,8)
@@ -127,32 +121,48 @@
 #define NET_26_12_SKALLOC
 #endif
 
+/* see <linux/security.h> */
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,13)
 #define HAVE_SOCK_SECURITY
 /* skb->nf_debug disappared completely in 2.6.13 */
 #define HAVE_SKB_NF_DEBUG
 #endif
 
-#define SYSCTL_IPSEC_DEFAULT_TTL sysctl_ip_default_ttl                      
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,14)
 /* skb->stamp changed to skb->tstamp in 2.6.14 */
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,14)
 #define HAVE_TSTAMP
 #define HAVE_INET_SK_SPORT
-#undef  SYSCTL_IPSEC_DEFAULT_TTL
-#define SYSCTL_IPSEC_DEFAULT_TTL IPSEC_DEFAULT_TTL
 #else
-#define HAVE_SKB_LIST
+#define HAVE_SKB_LIST 
 #endif
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,18) || SLE_VERSION_CODE >= 655616
+#define SYSCTL_IPSEC_DEFAULT_TTL sysctl_ip_default_ttl                      
+/* it seems 2.6.14 accidentally removed sysctl_ip_default_ttl */
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,14)
+#undef  SYSCTL_IPSEC_DEFAULT_TTL
+#define SYSCTL_IPSEC_DEFAULT_TTL IPSEC_DEFAULT_TTL
+#endif
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,18)
 #define HAVE_NEW_SKB_LINEARIZE
 #endif
 
 /* this is the best we can do to detect XEN, which makes
- *  * patches to linux/skbuff.h, making it look like 2.6.18 version 
- *   */
+ * patches to linux/skbuff.h, making it look like 2.6.18 version 
+ */
 #ifdef CONFIG_XEN
-#define HAVE_NEW_SKB_LINEARIZE
+# HAVE_NEW_SKB_LINEARIZE
+#endif
+
+/* And the same for SuSe kernels who have it before it got into the
+ * linus kernel.
+ */
+#ifdef SLE_VERSION_CODE
+# if SLE_VERSION_CODE >= 655616
+#  define HAVE_NEW_SKB_LINEARIZE
+# else
+#  warning "A Suse kernel was detected, but we are unsure if it requires HAVE_NEW_SKB_LINEARIZE"
+# endif
 #endif
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,19)
@@ -164,10 +174,18 @@
 #define nfmark mark
 #endif
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,21)
+#define ipsec_register_sysctl_table(a,b) register_sysctl_table(a)
+#define CTL_TABLE_PARENT
+#else
+#define ipsec_register_sysctl_table(a,b) register_sysctl_table(a,b)
+#endif
+ 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,22)
 /* need to include ip.h early, no longer pick it up in skbuff.h */
 #include <linux/ip.h>
 #  define HAVE_KERNEL_TSTAMP
+#  define HAVE_KMEM_CACHE_MACRO
 /* type of sock.sk_stamp changed from timeval to ktime  */
 #  define grab_socket_timeval(tv, sock)  { (tv) = ktime_to_timeval((sock).sk_stamp); }
 #else
@@ -186,17 +204,16 @@
 #  define skb_mac_header(skb)  ((skb)->mac.raw)
 #  define skb_set_mac_header(skb,off)  ((skb)->mac.raw = (skb)->data + (off))
 #endif
-
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,24)
-#define LINUX_PROCNET init_net.proc_net
-#else
-#define LINUX_PROCNET proc_net
-#endif
-
-
 /* turn a pointer into an offset for above macros */
 #define ipsec_skb_offset(skb, ptr) (((unsigned char *)(ptr)) - (skb)->data)
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,23)
+/* Try using the new kernel encaps hook for nat-t, instead of udp.c */
+#ifdef NOT_YET_FINISHED
+# define HAVE_UDP_ENCAP_CONVERT
+# endif
+#endif
+
 #ifdef NET_21
 #  include <linux/in6.h>
 #else
@@ -209,92 +226,7 @@
 #  define uint64_t __u64 
 #endif
 
-#ifdef NET_21
-# define ipsec_kfree_skb(a) kfree_skb(a)
-#else /* NET_21 */
-# define ipsec_kfree_skb(a) kfree_skb(a, FREE_WRITE)
-#endif /* NET_21 */
-
-#ifdef NETDEV_23
-#if 0
-#ifndef NETDEV_25
-#define device net_device
-#endif
-#endif
-
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,24)
-#define __ipsec_dev_get(x) __dev_get_by_name(&init_net, x)
-#define ipsec_dev_get(x) dev_get_by_name(&init_net, x)
-#else
-#define ipsec_dev_get(x) __dev_get_by_name(x)
-#define __ipsec_dev_get(x) __dev_get_by_name(x)
-#endif
-
-# define ipsec_dev_put(x) dev_put(x)
-# define __ipsec_dev_put(x) __dev_put(x)
-# define ipsec_dev_hold(x) dev_hold(x)
-#else /* NETDEV_23 */
-# define ipsec_dev_get dev_get
-# define __ipsec_dev_put(x) 
-# define ipsec_dev_put(x)
-# define ipsec_dev_hold(x) 
-#endif /* NETDEV_23 */
-
-#ifndef SPINLOCK
-#  include <linux/bios32.h>
-     /* simulate spin locks and read/write locks */
-     typedef struct {
-       volatile char lock;
-     } spinlock_t;
-
-     typedef struct {
-       volatile unsigned int lock;
-     } rwlock_t;                                                                     
-
-#  define spin_lock_init(x) { (x)->lock = 0;}
-#  define rw_lock_init(x) { (x)->lock = 0; }
-
-#  define spin_lock(x) { while ((x)->lock) barrier(); (x)->lock=1;}
-#  define spin_lock_irq(x) { cli(); spin_lock(x);}
-#  define spin_lock_irqsave(x,flags) { save_flags(flags); spin_lock_irq(x);}
-
-#  define spin_unlock(x) { (x)->lock=0;}
-#  define spin_unlock_irq(x) { spin_unlock(x); sti();}
-#  define spin_unlock_irqrestore(x,flags) { spin_unlock(x); restore_flags(flags);}
-
-#  define read_lock(x) spin_lock(x)
-#  define read_lock_irq(x) spin_lock_irq(x)
-#  define read_lock_irqsave(x,flags) spin_lock_irqsave(x,flags)
-
-#  define read_unlock(x) spin_unlock(x)
-#  define read_unlock_irq(x) spin_unlock_irq(x)
-#  define read_unlock_irqrestore(x,flags) spin_unlock_irqrestore(x,flags)
-
-#  define write_lock(x) spin_lock(x)
-#  define write_lock_irq(x) spin_lock_irq(x)
-#  define write_lock_irqsave(x,flags) spin_lock_irqsave(x,flags)
-
-#  define write_unlock(x) spin_unlock(x)
-#  define write_unlock_irq(x) spin_unlock_irq(x)
-#  define write_unlock_irqrestore(x,flags) spin_unlock_irqrestore(x,flags)
-#endif /* !SPINLOCK */
-
-#ifndef SPINLOCK_23
-#  define spin_lock_bh(x)  spin_lock_irq(x)
-#  define spin_unlock_bh(x)  spin_unlock_irq(x)
-
-#  define read_lock_bh(x)  read_lock_irq(x)
-#  define read_unlock_bh(x)  read_unlock_irq(x)
-
-#  define write_lock_bh(x)  write_lock_irq(x)
-#  define write_unlock_bh(x)  write_unlock_irq(x)
-#endif /* !SPINLOCK_23 */
-
-#ifndef HAVE_NETDEV_PRINTK
-#define netdev_printk(sevlevel, netdev, msglevel, format, arg...) \
-	printk(sevlevel "%s: " format , netdev->name , ## arg)
-#endif
-
+#if __KERNEL__
 #if LINUX_VERSION_CODE <= KERNEL_VERSION(2,6,0)
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0) 
 #include "openswan/ipsec_kern24.h"
@@ -302,7 +234,7 @@
 #error "kernels before 2.4 are not supported at this time"
 #endif
 #endif
-
+#endif
 
 #endif /* _OPENSWAN_KVERSIONS_H */
 
