@@ -15,7 +15,6 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_param.h,v 1.29.6.5 2008-02-18 16:27:19 paul Exp $
  *
  */
 
@@ -30,13 +29,23 @@
 #ifndef _IPSEC_PARAM_H_
 
 #ifdef __KERNEL__
-#include "ipsec_kversion.h"
+
+#include "openswan/ipsec_kversion.h"
 
 /* Set number of ipsecX virtual devices here. */
 /* This must be < exp(field width of IPSEC_DEV_FORMAT) */
 /* It must also be reasonable so as not to overload the memory and CPU */
 /* constraints of the host. */
-#define IPSEC_NUM_IF	4
+#ifdef CONFIG_KLIPS_IF_MAX
+#define IPSEC_NUM_IFMAX CONFIG_KLIPS_IF_MAX
+#endif
+#ifndef IPSEC_NUM_IFMAX
+#define IPSEC_NUM_IFMAX	64
+#endif
+
+/* default number of ipsecX devices to create */
+#define IPSEC_NUM_IF	2
+
 /* The field width must be < IF_NAM_SIZ - strlen("ipsec") - 1. */
 /* With "ipsec" being 5 characters, that means 10 is the max field width */
 /* but machine memory and CPU constraints are not likely to tollerate */
@@ -45,6 +54,8 @@
 /* for now, no "0"-padding should be used (which would have been helpful */
 /* to make text-searches work */
 #define IPSEC_DEV_FORMAT "ipsec%d"
+#define MAST_DEV_FORMAT "mast%d"
+
 /* For, say, 500 virtual ipsec devices, I would recommend: */
 /* #define IPSEC_NUM_IF	500 */
 /* #define IPSEC_DEV_FORMAT "ipsec%03d" */
@@ -61,6 +72,7 @@
 #else /* CONFIG_KLIPS_BIGGATE */
 # define SADB_HASHMOD	257
 #endif /* CONFIG_KLIPS_BIGGATE */
+
 #endif /* __KERNEL__ */
 
 /*
@@ -68,14 +80,10 @@
  * maximum number of SAs that KLIPS can concurrently deal with, plus enough
  * space for keeping expired SAs around.
  *
- * TABLE_MAX_WIDTH is the number of bits that we will use.
+ * TABLE_IDX_WIDTH is the number of bits that we will use.
  * MAIN_TABLE_WIDTH is the number of bits used for the primary index table.
  *
  */
-#ifndef IPSEC_SA_REF_TABLE_IDX_WIDTH
-# define IPSEC_SA_REF_TABLE_IDX_WIDTH 16
-#endif
-
 #ifndef IPSEC_SA_REF_MAINTABLE_IDX_WIDTH 
 # define IPSEC_SA_REF_MAINTABLE_IDX_WIDTH 4 
 #endif
@@ -159,25 +167,20 @@ extern int sysctl_ipsec_regress_pfkey_lossage;
 #ifndef KLIPS_PFKEY_ACQUIRE_LOSSAGE
 # ifdef CONFIG_KLIPS_PFKEY_ACQUIRE_LOSSAGE
 #  define KLIPS_PFKEY_ACQUIRE_LOSSAGE 100
+# else /* CONFIG_KLIPS_PFKEY_ACQUIRE_LOSSAGE */
+/* not by default! */
+#  define KLIPS_PFKEY_ACQUIRE_LOSSAGE 0
 # endif /* CONFIG_KLIPS_PFKEY_ACQUIRE_LOSSAGE */
-#else
-#define KLIPS_PFKEY_ACQUIRE_LOSSAGE 0
 #endif /* KLIPS_PFKEY_ACQUIRE_LOSSAGE */
 
-#else /* CONFIG_KLIPS_REGRESS */
-#define KLIPS_PFKEY_ACQUIRE_LOSSAGE 0
-
 #endif /* CONFIG_KLIPS_REGRESS */
 
 
 /*
  * debugging routines.
  */
-#define KLIPS_ERROR(flag, format, args...) if(printk_ratelimit() || flag) printk(KERN_ERR "KLIPS " format, ## args)
 #ifdef CONFIG_KLIPS_DEBUG
-#include <linux/ip.h>
-extern void ipsec_print_ip(struct iphdr *ip);
-
+        #define KLIPS_ERROR(flag, format, args...) if(printk_ratelimit() || flag) printk(KERN_ERR "KLIPS " format, ## args)
 	#define KLIPS_PRINT(flag, format, args...) \
 		((flag) ? printk(KERN_INFO format , ## args) : 0)
 	#define KLIPS_PRINTMORE(flag, format, args...) \
@@ -187,6 +190,7 @@ extern void ipsec_print_ip(struct iphdr *ip);
 	#define KLIPS_SATOT(flag, sa, format, dst, dstlen) \
 		((flag) ? satot(sa, format, dst, dstlen) : 0)
 #else /* CONFIG_KLIPS_DEBUG */
+        #define KLIPS_ERROR(flag, format, args...) if(printk_ratelimit()) printk(KERN_ERR "KLIPS " format, ## args)
 	#define KLIPS_PRINT(flag, format, args...) do ; while(0)
 	#define KLIPS_PRINTMORE(flag, format, args...) do ; while(0)
 	#define KLIPS_IP_PRINT(flag, ip) do ; while(0)
@@ -258,9 +262,10 @@ extern void ipsec_print_ip(struct iphdr *ip);
 
 /*
  * $Log: ipsec_param.h,v $
- * Revision 1.29.6.5  2008-02-18 16:27:19  paul
- * include linux/ip.h for struct iphdr (bug 814) - patch by sedrez
- *
+<<<<<<< HEAD:linux/include/openswan/ipsec_param.h
+ * Revision 1.31  2005/08/12 15:01:38  mcr
+ * 	attempt to #undef CONFIG_IPSEC_NAT_TRAVERSAL if it is =0.
+=======
  * Revision 1.29.6.4  2007/09/05 02:30:06  paul
  * KLIPS_SATOT macro. Patch by David McCullough
  *
@@ -270,9 +275,11 @@ extern void ipsec_print_ip(struct iphdr *ip);
  * Revision 1.29.6.2  2005/11/27 21:40:14  paul
  * Pull down TTL fixes from head. this fixes "Unknown symbol sysctl_ip_default_ttl"
  * in for klips as module.
+>>>>>>> 84dee3e...   patches for 2.6.22, skb-pointer-changes:linux/include/openswan/ipsec_param.h
  *
- * Revision 1.29.6.1  2005/08/12 16:24:18  ken
- * Pull in NAT-T compile logic from HEAD
+ * Revision 1.30  2005/08/05 08:50:45  mcr
+ * 	move #include of skbuff.h to a place where
+ * 	we know it will be kernel only code.
  *
  * Revision 1.29  2005/01/26 00:50:35  mcr
  * 	adjustment of confusion of CONFIG_IPSEC_NAT vs CONFIG_KLIPS_NAT,
