@@ -13,7 +13,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: ipsec_policy.h,v 1.7.6.1 2005-07-26 01:53:07 ken Exp $
+ * RCSID $Id: ipsec_policy.h,v 1.8 2005/07/26 01:12:38 mcr Exp $
  */
 #define	_IPSEC_POLICY_H 	/* seen it, no need to see it again */
 
@@ -80,7 +80,8 @@ enum ipsec_authentication_algo {
   AH_DES=4,
   AH_SHA2_256=5,
   AH_SHA2_384=6,
-  AH_SHA2_512=7
+  AH_SHA2_512=7,
+  AH_RIPEMD=8
 };
 
 /* IPsec ESP transform values
@@ -116,16 +117,23 @@ enum ipsec_comp_algo {
 };
 
 /* Identification type values
- * RFC 2407 The Internet IP security Domain of Interpretation for ISAKMP 4.6.2.1 
+ * RFC 2407 The Internet IP security Domain of Interpretation for
+ * ISAKMP 4.6.2.1
+ *
+ * Also for RFC4306. 
+ *
+ * enum ident_names;
  */
 
 enum ipsec_id_type {
+	ID_FROMCERT=         (-3),      /* taken from certificate */
   ID_IMPOSSIBLE=             (-2),	/* private to Pluto */
   ID_MYID=                   (-1),	/* private to Pluto */
   ID_NONE=                     0,	/* private to Pluto */
   ID_IPV4_ADDR=                1,
   ID_FQDN=                     2,
   ID_USER_FQDN=                3,
+  ID_RFC822_ADDR = ID_USER_FQDN,        /* RFC4306 */
   ID_IPV4_ADDR_SUBNET=         4,
   ID_IPV6_ADDR=                5,
   ID_IPV6_ADDR_SUBNET=         6,
