@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: goodmask.c,v 1.12 2004-07-10 07:43:47 mcr Exp $
+ * RCSID $Id: goodmask.c,v 1.12 2004/07/10 07:43:47 mcr Exp $
  */
 #include "openswan.h"
 
@@ -98,3 +98,46 @@ int n;
 		result.s_addr = 0;	/* best error report we can do */
 	return result;
 }
+
+/*
+ - bitstomask6 - return a mask with this many high bits on
+ */
+struct in6_addr
+bitstomask6(n)
+int n;
+{
+	struct in6_addr result;
+
+	if (n > 0 && n <= 32) {
+		result.s6_addr32[0] = htonl(~((1UL << (ABITS - n)) - 1));
+		result.s6_addr32[1]=0;
+		result.s6_addr32[2]=0;
+		result.s6_addr32[3]=0;
+	}
+	else if (n > 32 && n <= 64) {
+		result.s6_addr32[0]=0xffffffffUL;
+		result.s6_addr32[1] = htonl(~((1UL << (ABITS - n)) - 1));
+		result.s6_addr32[2]=0;
+		result.s6_addr32[3]=0;
+	}
+	else if (n > 64 && n <= 96) {
+		result.s6_addr32[0]=0xffffffffUL;
+		result.s6_addr32[1]=0xffffffffUL;
+		result.s6_addr32[2] = htonl(~((1UL << (ABITS - n)) - 1));
+		result.s6_addr32[3]=0;
+	}
+	else if (n > 96 && n <= 128) {
+		result.s6_addr32[0]=0xffffffff;
+		result.s6_addr32[1]=0xffffffff;
+		result.s6_addr32[2]=0xffffffff;
+		result.s6_addr32[3] = htonl(~((1UL << (ABITS - n)) - 1));
+	}
+	else {
+		result.s6_addr32[0] = 0;
+		result.s6_addr32[0] = 0;
+		result.s6_addr32[0] = 0;
+		result.s6_addr32[0] = 0;
+	} 
+
+	return result;
+}
