@@ -53,7 +53,9 @@
 
 #include "sha1.h"
 #include "md5.h"
+#include "cookie.h"
 #include "crypto.h" /* requires sha1.h and md5.h */
+#include "spdb.h"
 
 /*
  * Global variables: had to go somewhere, might as well be this file.
@@ -369,9 +371,14 @@ delete_state(struct state *st)
 
     unreference_key(&st->st_peer_pubkey);
 
+    free_sa(st->st_sadb);
+    st->st_sadb=NULL;
+
     if (st->st_sec_in_use)
 	mpz_clear(&(st->st_sec));
 
+    pfreeany(st->st_firstpacket_me.ptr);
+    pfreeany(st->st_firstpacket_him.ptr);
     pfreeany(st->st_tpacket.ptr);
     pfreeany(st->st_rpacket.ptr);
     pfreeany(st->st_p1isa.ptr);
@@ -381,9 +388,13 @@ delete_state(struct state *st)
     pfreeany(st->st_ni.ptr);
     pfreeany(st->st_nr.ptr);
     pfreeany(st->st_skeyid.ptr);
-    pfreeany(st->st_skeyid_d.ptr);
-    pfreeany(st->st_skeyid_a.ptr);
-    pfreeany(st->st_skeyid_e.ptr);
+    pfreeany(st->st_skey_d.ptr);
+    pfreeany(st->st_skey_ai.ptr);
+    pfreeany(st->st_skey_ar.ptr);
+    pfreeany(st->st_skey_ei.ptr);
+    pfreeany(st->st_skey_er.ptr);
+    pfreeany(st->st_skey_pi.ptr);
+    pfreeany(st->st_skey_pr.ptr);
     pfreeany(st->st_enc_key.ptr);
     pfreeany(st->st_ah.our_keymat);
     pfreeany(st->st_ah.peer_keymat);
@@ -501,30 +512,6 @@ static bool same_phase1_sa_relations(struct state *this
 		&& this->st_clonedfrom == parent_sa));
 }
 
-/*
- * Delete all states that have somehow not ben deleted yet
- * but using interfaces that are going down
- */
- 
-void delete_states_dead_interfaces(void)
-{
-    struct state *st = NULL;
-    int i;
-
-    for (i = 0; st == NULL && i < STATE_TABLE_SIZE; i++)
-	for (st = statetable[i]; st != NULL;){
-	    struct state *this = st;
-	    st = st->st_hashchain_next;	/* before this is deleted */
-	    if (this->st_interface && this->st_interface->change == IFN_DELETE )
-	    {
-		openswan_log("deleting lasting state #%lu on interface (%s) which is shutting down",
-			this->st_serialno,
-			this->st_interface->ip_dev->id_vname);
-		delete_state(this);
-	    }
-	}
-}
-
 /*
  * delete all states that were created for a given connection.
  * if relations == TRUE, then also delete states that share
@@ -756,15 +743,27 @@ duplicate_state(struct state *st)
     nst->st_interface  = st->st_interface;
     nst->st_clonedfrom = st->st_serialno;
     nst->st_import     = st->st_import;
-
+    nst->st_ikev2      = st->st_ikev2;
 
 #   define clone_chunk(ch, name) \
 	clonetochunk(nst->ch, st->ch.ptr, st->ch.len, name)
 
+#if 0
     clone_chunk(st_skeyid_d, "st_skeyid_d in duplicate_state");
     clone_chunk(st_skeyid_a, "st_skeyid_a in duplicate_state");
     clone_chunk(st_skeyid_e, "st_skeyid_e in duplicate_state");
-    clone_chunk(st_enc_key, "st_enc_key in duplicate_state");
+#endif
+    clone_chunk(st_enc_key,  "st_enc_key in duplicate_state");
+
+    /* v2 duplication of state */
+    clone_chunk(st_skeyseed, "st_skeyseed in duplicate_state");
+    clone_chunk(st_skey_d,   "st_skey_d in duplicate_state");
+    clone_chunk(st_skey_ai,  "st_skey_ai in duplicate_state");
+    clone_chunk(st_skey_ar,  "st_skey_ar in duplicate_state");
+    clone_chunk(st_skey_ei,  "st_skey_ei in duplicate_state");
+    clone_chunk(st_skey_er,  "st_skey_er in duplicate_state");
+    clone_chunk(st_skey_pi,  "st_skey_pi in duplicate_state");
+    clone_chunk(st_skey_pr,  "st_skey_pr in duplicate_state");
 
 #   undef clone_chunk
 
@@ -789,23 +788,24 @@ void for_each_state(void *(f)(struct state *, void *data), void *data)
 #endif
 
 /*
- * Find a state object.
+ * Find a state object for an IKEv1 state
  */
 struct state *
-find_state(const u_char *icookie
-, const u_char *rcookie
-, const ip_address *peer UNUSED
-, msgid_t /*network order*/ msgid)
+find_state_ikev1(const u_char *icookie
+		 , const u_char *rcookie
+		 , const ip_address *peer UNUSED
+		 , msgid_t /*network order*/ msgid)
 {
     struct state *st = *state_hash(icookie, rcookie);
 
     while (st != (struct state *) NULL)
     {
 	if (memcmp(icookie, st->st_icookie, COOKIE_SIZE) == 0
-	    && memcmp(rcookie, st->st_rcookie, COOKIE_SIZE) == 0)
+	    && memcmp(rcookie, st->st_rcookie, COOKIE_SIZE) == 0
+	    && st->st_ikev2 == FALSE)
 	{
 	    DBG(DBG_CONTROL,
-		DBG_log("peer and cookies match on #%ld, provided msgid %08lx vs %08lx"
+		DBG_log("v1 peer and cookies match on #%ld, provided msgid %08lx vs %08lx"
 			, st->st_serialno
 			, (long unsigned)ntohl(msgid)
 			, (long unsigned)ntohl(st->st_msgid)));
@@ -817,9 +817,81 @@ find_state(const u_char *icookie
 
     DBG(DBG_CONTROL,
 	if (st == NULL)
-	    DBG_log("state object not found");
+	    DBG_log("v1 state object not found");
 	else
-	    DBG_log("state object #%lu found, in %s"
+	    DBG_log("v1 state object #%lu found, in %s"
+		, st->st_serialno
+		, enum_show(&state_names, st->st_state)));
+
+    return st;
+}
+
+/*
+ * Find a state object for an IKEv2 state.
+ * Note: only finds parent states.
+ */
+struct state *
+find_state_ikev2_parent(const u_char *icookie
+			, const u_char *rcookie)
+{
+    struct state *st = *state_hash(icookie, rcookie);
+
+    while (st != (struct state *) NULL)
+    {
+	if (memcmp(icookie, st->st_icookie, COOKIE_SIZE) == 0
+	    && memcmp(rcookie, st->st_rcookie, COOKIE_SIZE) == 0
+	    && st->st_ikev2 == TRUE
+	    && st->st_clonedfrom == 0)
+	{
+	    DBG(DBG_CONTROL,
+		DBG_log("v2 peer and cookies match on #%ld"
+			, st->st_serialno));
+	    break;
+	}
+	st = st->st_hashchain_next;
+    }
+
+    DBG(DBG_CONTROL,
+	if (st == NULL)
+	    DBG_log("v2 state object not found");
+	else
+	    DBG_log("v2 state object #%lu found, in %s"
+		, st->st_serialno
+		, enum_show(&state_names, st->st_state)));
+
+    return st;
+}
+
+/*
+ * Find a state object for an IKEv2 state, a response that includes a msgid.
+ */
+struct state *
+find_state_ikev2_child(const u_char *icookie
+		       , const u_char *rcookie
+		       , msgid_t msgid)
+{
+    struct state *st = *state_hash(icookie, rcookie);
+
+    while (st != (struct state *) NULL)
+    {
+	if (memcmp(icookie, st->st_icookie, COOKIE_SIZE) == 0
+	    && memcmp(rcookie, st->st_rcookie, COOKIE_SIZE) == 0
+	    && st->st_ikev2 == TRUE
+	    && st->st_msgid == msgid)
+	{
+	    DBG(DBG_CONTROL,
+		DBG_log("v2 peer, cookies and msgid match on #%ld"
+			, st->st_serialno));
+	    break;
+	}
+	st = st->st_hashchain_next;
+    }
+
+    DBG(DBG_CONTROL,
+	if (st == NULL)
+	    DBG_log("v2 state object not found");
+	else
+	    DBG_log("v2 state object #%lu found, in %s"
 		, st->st_serialno
 		, enum_show(&state_names, st->st_state)));
 
