@@ -42,8 +42,9 @@
  * than specified by draft-jenkins-ipsec-rekeying-06.txt.
  */
 
-typedef u_int32_t msgid_t;	/* Network order! */
+/* msgid_t defined in defs.h */
 #define MAINMODE_MSGID    ((msgid_t) 0)
+#define INVALID_MSGID     0xffffffff
 
 struct state;	/* forward declaration of tag */
 extern void reserve_msgid(struct state *isakmp_sa, msgid_t msgid);
@@ -58,22 +59,29 @@ extern msgid_t generate_msgid(struct state *isakmp_sa);
  * in the Transaction Payload.
  * Names are chosen to match corresponding names in state.
  */
-struct oakley_trans_attrs {
+struct trans_attrs {
     u_int16_t encrypt;		/* Encryption algorithm */
     u_int16_t enckeylen;	/* encryption key len (bits) */
-    const struct encrypt_desc *encrypter;	/* package of encryption routines */
-    oakley_hash_t hash;		/* Hash algorithm */
-    const struct hash_desc *hasher;	/* package of hashing routines */
-    oakley_auth_t auth;		/* Authentication method */
+    oakley_hash_t prf_hash;	/* Hash algorithm for PRF */
+    oakley_hash_t integ_hash;	/* Hash algorithm for integ */
+    
+    oakley_auth_t auth;		/* Authentication method (RSA,PSK) */
 #ifdef XAUTH
     u_int16_t xauth;            /* did we negotiate Extended Authentication? */
 #endif
-    const struct oakley_group_desc *group;	/* Oakley group */
+    u_int16_t                       groupnum;
+
     time_t life_seconds;	/* When this SA expires (seconds) */
     u_int32_t life_kilobytes;	/* When this SA is exhausted (kilobytes) */
-#if 0 /* not yet */
-    u_int16_t prf;		/* Pseudo Random Function */
-#endif
+
+    /* used in phase1/PARENT SA */
+    const struct encrypt_desc *encrypter; /* package of encryption routines */
+    const struct hash_desc *prf_hasher;	  /* package of hashing routines */
+    const struct hash_desc *integ_hasher; /* package of hashing routines */
+    const struct oakley_group_desc *group;	/* Oakley group */
+
+    /* used in phase2/CHILD_SA */
+    struct esp_info *ei;
 };
 
 /* IPsec (Phase 2 / Quick Mode) transform and attributes
@@ -85,14 +93,11 @@ struct oakley_trans_attrs {
  * in different places. Fix it up sometime.
  */
 struct ipsec_trans_attrs {
-    u_int8_t transid;	/* transform id */
-    ipsec_spi_t spi;	/* his SPI */
-    time_t life_seconds;		/* When this SA expires */
-    u_int32_t life_kilobytes;	/* When this SA expires */
+    struct trans_attrs   transattrs;
+    ipsec_spi_t spi;	         /* his SPI */
+    time_t life_seconds;	 /* When this SA expires */
+    u_int32_t life_kilobytes;	 /* When this SA expires */
     u_int16_t encapsulation;
-    ipsec_auth_t auth;            
-    u_int16_t key_len;
-    u_int16_t key_rounds;
 #if 0 /* not implemented yet */
     u_int16_t cmprs_dict_sz;
     u_int32_t cmprs_alg;
@@ -109,9 +114,10 @@ struct ipsec_proto_info {
     u_char *peer_keymat;
 };
 
-/* internal state that
- * should get copied by god
- * Eistein would be proud
+/*
+ * internal state that
+ * should get copied by god... to the child SA state.
+ * this is to make Einstein happy.
  */
 
 struct hidden_variables {
@@ -139,6 +145,15 @@ struct hidden_variables {
                                   st->st_suspended_md_func=__FUNCTION__; \
                                   st->st_suspended_md_line=__LINE__; } while(0)
 
+struct traffic_selector {
+    u_int8_t  sin_family;
+    u_int8_t  ipprotoid;
+    u_int16_t startport;
+    u_int16_t endport;
+    ip_address low;
+    ip_address high;
+};
+
 /* state object: record the state of a (possibly nascent) SA
  *
  * Invariants (violated only during short transitions):
@@ -148,21 +163,23 @@ struct hidden_variables {
  */
 struct state
 {
-    so_serial_t        st_serialno;          /*serial number (for seniority) */
+    so_serial_t        st_serialno;          /* serial number (for seniority)*/
     so_serial_t        st_clonedfrom;        /* serial number of parent */
     int                st_usage;
 
-    struct connection *st_connection;          /* connection for this SA */
-    int                st_whack_sock;          /* fd for our Whack TCP socket.
-                                                * Single copy: close when
-						* freeing struct.
-                                                */
+    bool               st_ikev2;             /* is this an IKEv2 state? */
 
-    struct msg_digest *st_suspended_md;        /* suspended state-transition */
+    struct connection *st_connection;        /* connection for this SA */
+    int                st_whack_sock;        /* fd for our Whack TCP socket.
+                                              * Single copy: close when
+				              * freeing struct.
+					      */
+
+    struct msg_digest *st_suspended_md;      /* suspended state-transition */
     const char        *st_suspended_md_func;
     int                st_suspended_md_line;
 
-    struct oakley_trans_attrs st_oakley;
+    struct trans_attrs st_oakley;
 
     struct ipsec_proto_info st_ah;
     struct ipsec_proto_info st_esp;
@@ -188,37 +205,51 @@ struct state
     ip_address         st_localaddr;           /* where to send them from */
     u_int16_t          st_localport;           
 
-    msgid_t            st_msgid;               /* MSG-ID from header.  Network Order! */
-    bool               st_reserve_msgid;       /* if TRUE, then message id has been reserved already */
+    struct db_sa      *st_sadb;
+
+    /* IKEv1 things */
+    msgid_t            st_msgid;               /* MSG-ID from header.
+						  Network Order! */
+    bool               st_reserve_msgid;       /* if TRUE, then message id
+						  has been reserved already */
 
     msgid_t            st_msgid_phase15;       /* msgid for phase 1.5 */
     msgid_t            st_msgid_phase15b;      /* msgid for phase 1.5 */
-
     /* only for a state representing an ISAKMP SA */
     struct msgid_list  *st_used_msgids;        /* used-up msgids */
 
-/* symmetric stuff */
+    /* IKEv2 things */
+    /* message ID sequence for things we send (as initiator) */
+    msgid_t            st_msgid_lastack;       /* last one peer acknowledged */
+    msgid_t            st_msgid_nextuse;       /* next one to use */
 
-  /* initiator stuff */
+    /* message ID sequence for things we receive (as responder) */
+    msgid_t            st_msgid_lastrecv;      /* last one peer sent */
+
+
+    /* symmetric stuff */
+
+    /* initiator stuff */
     chunk_t            st_gi;                  /* Initiator public value */
     u_int8_t           st_icookie[COOKIE_SIZE];/* Initiator Cookie */
     chunk_t            st_ni;                  /* Ni nonce */
 
-  /* responder stuff */
+    /* responder stuff */
     chunk_t            st_gr;                  /* Responder public value */
     u_int8_t           st_rcookie[COOKIE_SIZE];/* Responder Cookie */
     chunk_t            st_nr;                  /* Nr nonce */
 
 
-  /* my stuff */
-
+    /* my stuff */
     chunk_t            st_tpacket;             /* Transmitted packet */
+    chunk_t            st_firstpacket_me;      /* copy of my message 1 */
+    chunk_t            st_firstpacket_him;     /* copy of his message 1 */
 
     /* Phase 2 ID payload info about my user */
     u_int8_t           st_myuserprotoid;       /* IDcx.protoid */
     u_int16_t          st_myuserport;
 
-  /* his stuff */
+    /* his stuff */
 
     chunk_t            st_rpacket;             /* Received packet */
 
@@ -226,8 +257,7 @@ struct state
     u_int8_t           st_peeruserprotoid;     /* IDcx.protoid */
     u_int16_t          st_peeruserport;
 
-/* end of symmetric stuff */
-
+    /* end of symmetric stuff */
     u_int8_t           st_sec_in_use;      /* bool: does st_sec hold a value */
     MP_INT             st_sec;             /* Our local secret value */
     chunk_t            st_sec_chunk;       /* copy of above */
@@ -246,7 +276,8 @@ struct state
 
     enum state_kind    st_state;               /* State of exchange */
     u_int8_t           st_retransmit;          /* Number of retransmits */
-    unsigned long      st_try;                 /* number of times rekeying attempted */
+    unsigned long      st_try;                 /* number of times rekeying
+						  attempted */
                                                /* 0 means the only time */
     time_t             st_margin;              /* life after EVENT_SA_REPLACE*/
     unsigned long      st_outbound_count;      /* traffic through eroute */
@@ -262,10 +293,21 @@ struct state
     chunk_t            st_p1isa;               /* Phase 1 initiator SA
 						  (Payload) for HASH
 					       */
-    chunk_t            st_skeyid;              /* Key material */
-    chunk_t            st_skeyid_d;            /* KM for non-ISAKMP key derivation */
-    chunk_t            st_skeyid_a;            /* KM for ISAKMP authentication */
-    chunk_t            st_skeyid_e;            /* KM for ISAKMP encryption */
+#define st_skeyid   st_skeyseed
+    chunk_t            st_skeyseed;            /* Key material */
+#define st_skeyid_d st_skey_d
+    chunk_t            st_skey_d;        /* KM for non-ISAKMP key derivation */
+#define st_skeyid_a st_skey_ai
+    chunk_t            st_skey_ai;       /* KM for ISAKMP authentication */
+    chunk_t            st_skey_ar;       /* KM for ISAKMP authentication */
+#define st_skeyid_e st_skey_ei
+    chunk_t            st_skey_ei;       /* KM for ISAKMP encryption */
+    chunk_t            st_skey_er;       /* KM for ISAKMP encryption */
+    chunk_t            st_skey_pi;       /* KM for ISAKMP encryption */
+    chunk_t            st_skey_pr;       /* KM for ISAKMP encryption */
+    struct connection *st_childsa;       /* connection included in AUTH */
+    struct traffic_selector st_ts_this, st_ts_that;
+
     u_char             st_iv[MAX_DIGEST_LEN];  /* IV for encryption */
     u_char             st_old_iv[MAX_DIGEST_LEN];  /* IV for encryption */
     u_char             st_new_iv[MAX_DIGEST_LEN];
@@ -277,7 +319,8 @@ struct state
 
     chunk_t            st_enc_key;             /* Oakley Encryption key */
 
-    struct event      *st_event;               /* backpointer for certain events */
+    struct event      *st_event;               /* backpointer for certain
+						  events */
     struct state      *st_hashchain_next;      /* Next in list */
     struct state      *st_hashchain_prev;      /* Previous in list */
 
@@ -289,12 +332,13 @@ struct state
     /* RFC 3706 Dead Peer Detection */
     time_t              st_last_dpd;            /* Time of last DPD transmit */
     u_int32_t           st_dpd_seqno;           /* Next R_U_THERE to send */
-    u_int32_t           st_dpd_expectseqno;     /* Next R_U_THERE_ACK to receive */
+    u_int32_t           st_dpd_expectseqno;     /* Next R_U_THERE_ACK
+						   to receive */
     u_int32_t           st_dpd_peerseqno;       /* global variables */
-    struct event        *st_dpd_event;          /* backpointer for DPD events */
+    struct event       *st_dpd_event;          /* backpointer for DPD events */
 
-
-    u_int32_t	      st_seen_vendorid;	  /* Bit field about recognized Vendor ID */
+    u_int32_t           st_seen_vendorid;      /* Bit field about
+						  recognized Vendor ID */
     struct isakmp_quirks quirks;          /* work arounds for faults in other
  					   * products */
     
@@ -323,7 +367,7 @@ extern void rekey_p2states_by_connection(struct connection *c);
 
 extern struct state
     *duplicate_state(struct state *st),
-    *find_state(const u_char *icookie
+    *find_state_ikev1(const u_char *icookie
 	, const u_char *rcookie
 	, const ip_address *peer
 	, msgid_t msgid),
@@ -333,11 +377,25 @@ extern struct state
     *find_phase1_state(const struct connection *c, lset_t ok_states),
     *find_sender(size_t packet_len, u_char *packet);
 
+extern struct state *find_state_ikev2_parent(const u_char *icookie
+					     , const u_char *rcookie);
+
+extern struct state *find_state_ikev2_child(const u_char *icookie
+					    , const u_char *rcookie
+					    , msgid_t msgid);
+
 extern struct state *find_info_state(const u_char *icookie
 				     , const u_char *rcookie
 				     , const ip_address *peer
 				     , msgid_t msgid);
 
+extern void initialize_new_state(struct state *st
+			       , struct connection *c
+			       , lset_t policy
+			       , int try
+			       , int whack_sock
+			       , enum crypto_importance importance);
+
 extern void show_states_status(void);
 
 #if 1
@@ -360,7 +418,6 @@ extern void set_state_ike_endpoints(struct state *st
 				    , struct connection *c);
 
 extern void delete_cryptographic_continuation(struct state *st);
-extern void delete_states_dead_interfaces(void);
 
 #endif /* _STATE_H */
 
