@@ -11,7 +11,6 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: vendor.h,v 1.13.2.8 2008-06-16 01:03:04 paul Exp $
  */
 
 #ifndef _VENDOR_H_
@@ -57,9 +56,13 @@ enum known_vendorid {
   VID_OPENSWANSELF	    =36,
   VID_NCP                   =37,
   VID_CISCO_IOS             =38,
-  VID_VISTA_AUTHIP          =39,
-  VID_VISTA_AUTHIP2         =40,
-  VID_VISTA_AUTHIP3         =41,
+  VID_SONICWALL_1           =39,
+  VID_SONICWALL_2           =40,
+
+/* World of Microsoft */
+  VID_VISTA_AUTHIP	    =51,
+  VID_VISTA_AUTHIP2	    =52,
+  VID_VISTA_AUTHIP3	    =53,
 
 
   /* 101 - 200 : NAT-Traversal */
@@ -71,8 +74,8 @@ enum known_vendorid {
   VID_NATT_IETF_02_N         =106,
   VID_NATT_IETF_02           =107,
   VID_NATT_IETF_03           =108,
-  VID_NATT_RFC               =109,
-  VID_NATT_DRAFT_IETF_IPSEC_NAT_T_IKE = 110,
+  VID_NATT_RFC               =109,               
+  VID_NATT_DRAFT_IETF_IPSEC_NAT_T_IKE =110,
   VID_NATT_IETF_05           =111,
 
 /* 
@@ -88,8 +91,7 @@ enum known_vendorid {
   VID_MISC_DPD               =202,
   VID_MISC_HEARTBEAT_NOTIFY  =203,
   VID_MISC_FRAGMENTATION     =204,
-  VID_INITIAL_CONTACT        =205,
-  VID_MISC_IKEv2             =206
+  VID_INITIAL_CONTACT        =205
 
 };
 
@@ -99,6 +101,8 @@ struct msg_digest;
 void handle_vendorid (struct msg_digest *md, const char *vid, size_t len, struct state *st);
 
 bool out_vendorid (u_int8_t np, pb_stream *outs, enum known_vendorid vid);
+bool out_vid(u_int8_t np, pb_stream *outs, unsigned int vid);
+
 
 extern const char compile_time_interop_options[];
 
